rnalysis.filtering.DESeqFilter.filter\_abs\_log2\_fold\_change
==============================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: DESeqFilter.filter_abs_log2_fold_change